<?php

namespace Drp\NativeEventApp\Enums;

use BenSampo\Enum\Contracts\LocalizedEnum;
use BenSampo\Enum\Enum;
use Drp\NativeEventApp\EmailAddress;
use Drp\NativeEventApp\PhoneNumber;
use Illuminate\Support\Arr;

final class AuthMethod extends Enum implements LocalizedEnum
{
    const SMS = 'SMS';
    const EMAIL = 'EMAIL';

    public function getNotificationDriver(): string
    {
        return Arr::get([
            self::SMS => 'nexmo',
            self::EMAIL => 'mail',
        ], $this->value);
    }

    /**
     * @return mixed
     */
    public function toObject(?string $value)
    {
        $objectClass = Arr::get([
            self::SMS => PhoneNumber::class,
            self::EMAIL => EmailAddress::class,
        ], $this->value);

        return new $objectClass($value);
    }

    public static function getLocalizationKey(): string
    {
        return 'NativeEventApp::authMethods';
    }
}
