<?php

namespace Drp\NativeEventApp\GraphQL\Queries;

use Drp\NativeEventApp\Auth\Facades\AuthInfoFinder;
use Drp\NativeEventApp\Contracts\MagicLinkSigner;
use Drp\NativeEventApp\Exceptions\NoAvailableContactDetails;

class AuthInfo
{
    /**
     * @var \Drp\NativeEventApp\Contracts\MagicLinkSigner
     */
    private $linkSigner;

    public function __construct(MagicLinkSigner $linkSigner)
    {
        $this->linkSigner = $linkSigner;
    }

    //phpcs:ignore
    public function __invoke($rootValue, array $args): array
    {
        $this->linkSigner->verify($args['authIdentifier'], $args['expiry'], $args['signature']);

        $authSource = AuthInfoFinder::retrieve($args['authIdentifier']);

        throw_if($authSource->contactDetails()->isEmpty(), NoAvailableContactDetails::class);

        return [
            'title' => config('native-event-app.details.application_name'),
            'contactMethods' => $authSource->contactDetails(),
            'minimumAppVersion' => $authSource->getMinimumVersion(),
        ];
    }
}
