<?php

namespace Drp\NativeEventApp\Notifications;

use Drp\NativeEventApp\Contracts\TokenAuthenticatable;
use Drp\NativeEventApp\Enums\AuthMethod;
use Drp\NativeEventApp\Mail\AppVerificationEmail;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Mail\Mailable;
use Illuminate\Notifications\Messages\NexmoMessage;
use Illuminate\Notifications\Notification;

class SendAuthCode extends Notification
{
    use Queueable;

    /**  @var string */
    public $tokenCode;

    /**
     * @var AuthMethod
     */
    public $authMethod;

    public function __construct(AuthMethod $authMethod, string $tokenCode)
    {
        $this->tokenCode = $tokenCode;
        $this->authMethod = $authMethod;
    }

    public function via(): array
    {
        return [$this->authMethod->getNotificationDriver()];
    }

    public function toMail(TokenAuthenticatable $notifiable): Mailable
    {
        return (new AppVerificationEmail($notifiable, $this->tokenCode));
    }

    public function toNexmo(): NexmoMessage
    {
        return (new NexmoMessage)->content(
            str_replace(':code', $this->tokenCode, config('native-event-app.verification.sms.message'))
        );
    }

    public function toArray(): array
    {
        return [];
    }
}
